@@ -17,7 +17,7 @@ Here is an example that does so.
 ```rust
 use bgpkit_parser::BgpkitParser;
 fn main() {
-    let parser = BgpkitParser::new("http://archive.routeviews.org/bgpdata/2021.10/UPDATES/updates.20211001.0000.bz2");
+    let parser = BgpkitParser::new("http://archive.routeviews.org/bgpdata/2021.10/UPDATES/updates.20211001.0000.bz2").unwrap();
     for elem in parser {
         println!("{}", elem)
     }
@@ -32,7 +32,7 @@ For example, counting the number of announcements/withdrawals in that file:
 use bgpkit_parser::BgpkitParser;
 fn main() {
     let url = "http://archive.routeviews.org/bgpdata/2021.10/UPDATES/updates.20211001.0000.bz2";
-    let count = BgpkitParser::new(url).into_iter().count();
+    let count = BgpkitParser::new(url).unwrap().into_iter().count();
     println!("total: {}", count);
 }
 ```
@@ -77,12 +77,12 @@ fn main(){
         // create a parser that takes an URL and automatically determine
         // the file location and file type, and handles data download and
         // decompression streaming intelligently
-        let parser = BgpkitParser::new(item.url.as_str());
+        let parser = BgpkitParser::new(item.url.as_str()).unwrap();
 
         // iterating through the parser. the iterator returns `BgpElem` one at a time.
         let elems = parser.into_elem_iter().map(|elem|{
             if let Some(origins) = &elem.origin_asns {
-                if origins.contains(&13335) {
+                if origins.contains(&13335.into()) {
                     Some(elem)
                 } else {
                     None
@@ -96,6 +96,37 @@ fn main(){
 }
 ```
 
+### Filtering BGP Messages
+
+BGPKIT Parser also has built-in [Filter] mechanism. When creating a new [BgpkitParser] instance,
+once can also call `add_filter` function to customize the parser to only show matching messages
+when iterating through [BgpElem]s.
+
+For all types of filters, check out the [Filter] enum documentation.
+
+```no_run
+use bgpkit_parser::BgpkitParser;
+
+/// This example shows how to parse a MRT file and filter by prefix.
+fn main() {
+    env_logger::Builder::from_env(env_logger::Env::default().default_filter_or("info")).init();
+
+    log::info!("downloading updates file");
+
+    // create a parser that takes the buffered reader
+    let parser = BgpkitParser::new("http://archive.routeviews.org/bgpdata/2021.10/UPDATES/updates.20211001.0000.bz2").unwrap()
+        .add_filter("prefix", "211.98.251.0/24").unwrap();
+
+    log::info!("parsing updates file");
+    // iterating through the parser. the iterator returns `BgpElem` one at a time.
+    for elem in parser {
+        log::info!("{}", &elem);
+    }
+    log::info!("done");
+}
+```
+
+
 ### Parsing Real-time Data Streams
 
 BGPKIT Parser also provides parsing functionalities for real-time data streams, including [RIS-Live][ris-live-url]
@@ -239,9 +270,55 @@ The main benefit of using [BgpElem] is that the analysis can be executed on a pe
 backend MRT data format (bgp4mp, tabledumpv1, tabledumpv2, etc.). The obvious drawback is that we will have to duplicate
 information to save at each elem, that consuming more memory.
 
+## RFCs Support
+
+We support most of the RFCs and plan to continue adding support for more recent RFCs in the future.
+Here is a list of relevant RFCs that we support or plan to add support.
+
+If you would like to see any specific RFC's support, please submit an issue on GitHub.
+
+### BGP
+
+- [X] [RFC 2042](https://datatracker.ietf.org/doc/html/rfc2042): Registering New BGP Attribute Types
+- [X] [RFC 3392](https://datatracker.ietf.org/doc/html/rfc3392): Capabilities Advertisement with BGP-4
+- [X] [RFC 4271](https://datatracker.ietf.org/doc/html/rfc4271): A Border Gateway Protocol 4 (BGP-4)
+- [X] [RFC 5065](https://datatracker.ietf.org/doc/html/rfc5065): Autonomous System Confederations for BGP
+- [X] [RFC 6793](https://datatracker.ietf.org/doc/html/rfc6793): BGP Support for Four-Octet Autonomous System (AS) Number Space
+- [X] [RFC 7911](https://datatracker.ietf.org/doc/html/rfc7911): Advertisement of Multiple Paths in BGP (ADD-PATH)
+- [ ] [RFC 8950](https://datatracker.ietf.org/doc/html/rfc8950): Advertising IPv4 Network Layer Reachability Information (NLRI) with an IPv6 Next Hop
+- [X] [RFC 9072](https://datatracker.ietf.org/doc/html/rfc9072): Extended Optional Parameters Length for BGP OPEN Message Updates
+
+### MRT
+
+- [X] [RFC 6396](https://datatracker.ietf.org/doc/html/rfc6396): Multi-Threaded Routing Toolkit (MRT) Routing Information Export Format
+- [ ] [RFC 6397](https://datatracker.ietf.org/doc/html/rfc6397): Multi-Threaded Routing Toolkit (MRT) Border Gateway Protocol (BGP) Routing Information Export Format with Geo-Location Extensions
+- [X] [RFC 8050](https://datatracker.ietf.org/doc/html/rfc8050): Multi-Threaded Routing Toolkit (MRT) Routing Information Export Format with BGP Additional Path Extensions
+
+### BMP
+
+- [X] [RFC 7854](https://datatracker.ietf.org/doc/html/rfc7854): BGP Monitoring Protocol (BMP)
+- [ ] [RFC 8671](https://datatracker.ietf.org/doc/html/rfc8671): Support for Adj-RIB-Out in the BGP Monitoring Protocol (BMP)
+
+### Communities
+
+We support normal communities, extended communities, and large communities.
+
+- [X] [RFC 1977](https://datatracker.ietf.org/doc/html/rfc1977): BGP Communities Attribute
+- [X] [RFC 4360](https://datatracker.ietf.org/doc/html/rfc4360): BGP Extended Communities Attribute
+- [X] [RFC 5668](https://datatracker.ietf.org/doc/html/rfc5668): 4-Octet AS Specific BGP Extended Community
+- [X] [RFC 5701](https://datatracker.ietf.org/doc/html/rfc5701): IPv6 Address Specific BGP Extended Community Attribute
+- [X] [RFC 7153](https://datatracker.ietf.org/doc/html/rfc7153): IANA Registries for BGP Extended Communities Updates 4360, 5701
+- [X] [RFC 8097](https://datatracker.ietf.org/doc/html/rfc8097): BGP Prefix Origin Validation State Extended Community
+- [X] [RFC 8092](https://datatracker.ietf.org/doc/html/rfc8092): BGP Large Communities
+
+### FlowSpec
+
+- [ ] [RFC 8955](https://datatracker.ietf.org/doc/html/rfc8955) Dissemination of Flow Specification Rules
+- [ ] [RFC 8956](https://datatracker.ietf.org/doc/html/rfc8956) Dissemination of Flow Specification Rules for IPv6
+- [ ] [RFC 9117](https://datatracker.ietf.org/doc/html/rfc9117) Revised Validation Procedure for BGP Flow Specifications Updates 8955
+
 [mrt-record-doc]: https://docs.rs/bgp-models/0.3.4/bgp_models/mrt/struct.MrtRecord.html
 */
-extern crate byteorder;
 extern crate chrono;
 extern crate ipnetwork;
 extern crate num_traits;
@@ -256,10 +333,13 @@ mod io;
 
 pub use parser::BgpkitParser;
 pub use parser::BgpElem;
-pub use parser::ParserError;
+pub use parser::ParserErrorKind;
 pub use parser::Elementor;
 pub use parser::iters::{ElemIterator, RecordIterator};
 pub use parser::bmp::parse_openbmp_msg;
 pub use parser::bmp::parse_bmp_msg;
 pub use parser::bmp::parse_openbmp_header;
 pub use parser::rislive::parse_ris_live_message;
+pub use parser::mrt::parse_mrt_record;
+pub use parser::utils::ReadUtils;
+pub use parser::filter::*;
